#ifndef OSD_BITMAPS
#define OSD_BITMAPS
#include "brightness.bitmap"
#include "brightness_mask.xbm"
#include "contrast.bitmap"
#include "contrast_mask.xbm"
#include "gamma.bitmap"
#include "gamma_mask.xbm"
// UNUSED
//#include "hue.bitmap"
//#include "hue_mask.xbm"
#include "saturation.bitmap"
#include "saturation_mask.xbm"
#endif
